@@ -18,12 +18,15 @@ class ErdCodeClass(enum.IntFlag):
     TEMPERATURE_CONTROL = auto()
     PERCENTAGE = auto()
     FLOW_RATE = auto()
+    LIQUID_VOLUME = auto()
     OVEN_SENSOR = auto()
     FRIDGE_SENSOR = auto()
     FREEZER_SENSOR = auto()
     DISPENSER_SENSOR = auto()
     DISHWASHER_SENSOR = auto() 
     LAUNDRY_SENSOR = auto() 
+    LAUNDRY_WASHER_SENSOR = auto()
+    LAUNDRY_DRYER_SENSOR = auto()
     MICROWAVE_SENSOR = auto()
     ADVANTIUM_SENSOR = auto()
     WATERFILTER_SENSOR = auto()
