@@ -72,12 +72,12 @@ class ErdCode(enum.Enum):
     LAUNDRY_DRYER_TEMPERATURE_OPTION = "0x2019"
     LAUNDRY_DRYER_SHEET_USAGE_CONFIGURATION = "0x2022"
     LAUNDRY_DRYER_SHEET_INVENTORY = "0x2023"
-    LAUNDRY_UNKNOWN2038 = "0x2038"
+    LAUNDRY_REMOTE_DELAY_CONTROL = "0x2038"
     LAUNDRY_REMOTE_STATUS = "0x2039"
-    LAUNDRY_WASHER_UNKNOWN203C = "0x203c"
+    LAUNDRY_WASHER_SMART_DISPENSE_TANK_STATUS = "0x203c"
     LAUNDRY_WASHER_SMART_DISPENSE = "0x203d"
     LAUNDRY_WASHER_UNKNOWN203E = "0x203e"
-    LAUNDRY_UNKNOWN2040 = "0x2040"
+    LAUNDRY_REMOTE_POWER_CONTROL = "0x2040"
     LAUNDRY_UNKNOWN2041 = "0x2041"
     LAUNDRY_DRYER_DRYNESSNEW_LEVEL = "0x204d"
     LAUNDRY_DRYER_TEMPERATURENEW_OPTION = "0x2050"
